@@ -3,11 +3,12 @@
 from zope.schema import Object
 from zope.container.interfaces import IContainer
 
-    
+
 class IStorage(IContainer):
     """A storage item handles the persistence of a given item.
     A storage has three main actions : store, retrieve, delete.
     """
+
     def clear():
         """Clears the content of the storage. Returns None.
         """
@@ -17,9 +18,10 @@ class IDelegatedStorage(IStorage):
     """A storage item handles the persistence of a given item.
     A storage has three main actions : store, retrieve, delete.
     """
+
     storage = Object(
-        title = u"Storage container",
-        description = u"A container to delegate the storage.",
-        schema = IStorage,
-        default=None
+        title=u"Storage container",
+        description=u"A container to delegate the storage.",
+        schema=IStorage,
+        default=None,
         )
